<h3>Download</h3> 

<p>Current version: <b>{{ version }}</b></p> 
<p>Get Distribute from the <a href="http://pypi.python.org/pypi/distribute"> Python Package Index</a>

<h3>Questions? Suggestions? Contributions?</h3>

<p>Visit the <a href="http://bitbucket.org/tarek/distribute">Distribute project page</a> </p>
